---
name: "\U0001F41B Bug Report"
about: Create a report for a reproducible bug
title: ''
labels: ''
assignees: ''

---

### Environment

* Installation type: <!-- snap/pip -->
* Python version:  <!-- Example: 3.6.9 -->
* Wilfred version:  <!-- Example: 1.0, 2.0, …, master -->

### Steps to Reproduce

<!-- What did you expect to happen? -->
### Expected Behavior

<!-- What happened instead? -->
### Observed Behavior
